bibliotheca Augustana

<<< Einführung
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge nôt ## Rohfassung von ## Karl Bartschs Edition: ## Der Nibelunge Nôt, ## mit den Abweichungen von Der Nibelunge Liet, ## den Lesarten sämmtlicher Handschriften ## und einem Wörterbuche, 1. Theil: Text, ## herausgegeben von Karl Bartsch. ## Leipzig: F.A. Brockhaus, 1870-1880 *) ## nach der Ausgabe ## im Oxford Text Archive ## (Das Nibelungenlied, Text 0202) ## Bearbeitung und Ergänzungen ## in Kursivschrift: Ulrich Harsch
___________________________________________________
###### 1 | Aventivre von den nibelvngen
###### 2 | Aventivre von sivride wie der erzogen wart
###### 3 | Aventivre wie sivrit ze wormze chome
###### 4 | Aventivre wie sivrit mit den sahsen streit
###### 5 | Aventivre wie sivrit chriemhilt alreste ersach
###### 6 | Aventivre wie gvnther gen isenlande nach prvnhilt fvor
###### 7 | Aventivre wie gvnther prvnhilde gewan
###### 8 | Aventivre wie sifrit nah den nibelvngen sinen rechen fvor
###### 9 | Aventivre wie sivrit ze wormez in botschefte fvor
###### 10 | Aventivre wie der kvnec gvnther zv wormze mit frov prvnhilt prvtte
###### 11 | Aventivre wie sifrit sin wip heim ze lande fvrte vnd wie er sit da heime brvotten
###### 12 | Aventivre wie gvnther sifriden zvo der hohzit bat
###### 13 | Aventivre wie chriemhilt mit ir man zer hochgecite fvr
###### 14 | Aventivre wie die chvniginne mit ander zerwrfen
###### 15 | Aventivre wie sifrit verraten wart
###### 16 | Aventivre wie sivrit ermort wart
###### 17 | Aventivre wie chriemhilt ir man klagte vnd wie man in begrvp
###### 18 | Aventivre wie chriemhilt da bestvnt vnd ir sweher dannen reit
###### 19 | Aventivre wie der nibelvnge hort ze wormze braht wart
###### 20 | Aventivre wie der chvnic ezele nah froen chriemhilt ze wormze sinen boten sande
###### 21 | Aventivre wie chriemhilt von wormze schiet do si gein den hvnen fvor
###### 22 | Aventivre wie chriemhilt vnd ezele brvten in der stat ze wienne
###### 23 | Aventivre wie krimhilt ir leit gedaht ze rechen
###### 24 | Aventivre wie die boten ze rine qvamen vnd wie si danne schieden
###### 25 | Aventivre wie die herren alle zen hevnen fvren
###### 26 | Aventivre wie si mit elsen vnd gelpfraten striten vnd wie in gelang
###### 27 | Aventivre wie der marchrave die kvnige mit ir rechen in sin hvs enpfie vnd wier ir sit pflach
###### 28 | Aventivre wie die nibelvnge ze ezeln bvrge chomen vnd wie si da enpfangen wrden
###### 29 | Aventivre wie hagene vnd volker vor chriemhilt sal sazen
###### 30 | Aventivre wie die kvnige mit ir rechen slafen giengen vnd wie in do geschach
###### 31 | Aventivre wie die herren ze kirchen giengen
###### 32 | Aventivre wie bloedelin erslagen wart
###### 33 | Aventivre wie die bvrgonden mit den hevnen striten
###### 34 | Aventivre wie si toten abe wvrfen
###### 35 | Aventivre wie irinch mit hagenen streit vnd wie im sit an im gelanch
###### 36 | Aventivre wie div chvnigin den sal beraiten hiez
###### 37 | Aventivre wie rvdeger erslagen wart
###### 38 | Aventivre wie des herren dietriches rechen alle wrden erslagen
###### 39 | Aventivre wie der herre dietrich gvntehern vnd hagenen betwanch
######  | ―――――― *) OTA-Anmerkung zum Text: Encoding format: Plain text, Text in capital letters. Probably (see note beneath) transcribed from: Der Nibelunge Nôt : mit den Abweichungen von der Nibelunge Liet, den Lesarten sämmtlicher Handschriften und einem Wörterbuche / herausgegeben von Karl Bartsch. -- Leipzig : F.A. Brockhaus, 1870-1880. -- 3 v. -- From Hs. B. (Hs. 857) in the Stiftsbibliothek Sankt Gallen. -- Contents: 1. T. Text -- 2. T. 1. Hälfte. Lesarten -- 2. T. 2. Hälfte. Wörterbuch. NOTE: From the cataloguer (M. Day): OTA records state this text was originally edited by Bartsch. Bartsch edited at least three versions of Nibelungenlied (NL) in his lifetime, one of which has been frequently revised, and is still in print (1). CHum. in 1973 referred to a text prepared by [Ray M.] Wakefield, [Michael S.] Batts, and [Stanley M.] Werbow, entitled Nibelungenlied (Handschrift B) (2). Checking with the bibliography in the 21st ed. of Bartsch and de Boor's NL, the edition of NL edited by Bartsch in 1870-1880 is also "Nach der Hs. B: hrsg." (3). From this information, I have concluded that the OTA text is in all probability derived from this 1870-80 edition. Batts (the depositor), in his "Die Form der Aventiuren im Nibelungenlied" (4), also refers to the 1870-80 ed. as a standard ed. based on Hs. B. (1) Boor, Helmut de (ed). Das Nibelungenlied: Nach der Ausgabe von Karl Bartsch. 21. Aufl. Wiesbaden: F.A. Brockhaus, 1979. (2) Computers and the Humanities, 7(4), Mar. 1973, p. 254. (3) Bartsch, Karl (ed). Der Nibelunge Nôt: mit den Abweichungen von der Nibelunge Liet, den Lesarten sämmtlicher Handschriften und einem Wörterbuche. Leipzig: F.A. Brockhaus, 1870-1880. (4) Batts, M.S. Die Form der Aventiuren im Nibelungenlied. Giessen: W. Schmitz, 1961. (Beiträge zur deutschen Philologie; Bd. 29)., p. 9.

<<< Einführung